"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = __importDefault(require("axios"));
class FranceTravailService {
    constructor() {
        this.accessToken = null;
        this.tokenExpiration = null;
        this.realm = '/partenaire';
        this.clientId = process.env.FRANCE_TRAVAIL_CLIENT_ID || '';
        this.clientSecret = process.env.FRANCE_TRAVAIL_CLIENT_SECRET || '';
        this.tokenUrl = process.env.FRANCE_TRAVAIL_TOKEN_URL || '';
        this.apiUrl = process.env.FRANCE_TRAVAIL_API_URL || '';
        this.scope = process.env.FRANCE_TRAVAIL_SCOPE || '';
    }
    authenticate() {
        return __awaiter(this, void 0, void 0, function* () {
            var _a;
            try {
                const response = yield axios_1.default.post(this.tokenUrl, null, {
                    params: {
                        realm: this.realm,
                        grant_type: 'client_credentials',
                        client_id: this.clientId,
                        client_secret: this.clientSecret,
                        scope: this.scope,
                    },
                    headers: {
                        'Content-Type': 'application/x-www-form-urlencoded',
                    },
                });
                this.accessToken = response.data.access_token;
                this.tokenExpiration = Date.now() + response.data.expires_in * 1000;
            }
            catch (error) {
                const axiosError = error;
                console.error('Authentication failed:', ((_a = axiosError.response) === null || _a === void 0 ? void 0 : _a.data) || axiosError.message);
                throw new Error('Failed to authenticate with France Travail API');
            }
        });
    }
    ensureValidToken() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.accessToken || (this.tokenExpiration && Date.now() >= this.tokenExpiration)) {
                yield this.authenticate();
            }
        });
    }
    getJobOffers(params) {
        return __awaiter(this, void 0, void 0, function* () {
            var _a;
            yield this.ensureValidToken();
            try {
                const response = yield axios_1.default.get(this.apiUrl, {
                    headers: {
                        Authorization: `Bearer ${this.accessToken}`,
                    },
                    params: Object.assign(Object.assign({}, params), { range: (params === null || params === void 0 ? void 0 : params.range) || '0-9' }),
                });
                return response.data;
            }
            catch (error) {
                const axiosError = error;
                console.error('Failed to fetch job offers:', ((_a = axiosError.response) === null || _a === void 0 ? void 0 : _a.data) || axiosError.message);
                throw new Error('Failed to fetch job offers from France Travail API');
            }
        });
    }
}
exports.default = new FranceTravailService();
